@@ -2,7 +2,6 @@ from operator import itemgetter
 from collections import Mapping, Set
 
 from .cross import basestring
-from .simple_funcs import identity
 from .strings import re_tester, re_finder, _re_type
 
 
@@ -15,7 +14,7 @@ def make_func(f, builtin=False, test=False):
     elif f is None:
         # pass None to builtin as predicate or mapping function for speed
         return None if builtin else \
-               bool if test else identity
+               bool if test else lambda x: x
     elif isinstance(f, (basestring, _re_type)):
         return re_tester(f) if test else re_finder(f)
     elif isinstance(f, (int, slice)):
